# 🗂 forg
Simple Folder organization in python. Based on Kalle Hallden snippet

## How It Works
 It creates a folder called forg on the downloads page, and based in a list of file extension, it creates subfolders in forg and move files there categorizing them by type.
